#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sayable
version:              1.2.6.0
visibility:           public
id:                   sayable-1.2.6.0-7j1RwjqNpHbAnkR423nlV8
key:                  sayable-1.2.6.0-7j1RwjqNpHbAnkR423nlV8
license:              ISC
copyright:            Galois Inc., 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Construction of context-adjusted pretty output
description:

    This package provides a set of data structures, classes and operators that
    facilitate the construction of a Prettyprinter Doc object.  The difference
    between this an Prettyprinter is:

    * Additional "saytag" parameter that can be used to control the Doc rendering.

    * Brevity of syntax (using operators) designed to enhance conversion of
    arguments and readability of messages and conversion

category:             Text
abi:                  e3a2ba8abd068d74921bd2aeec9d2260
exposed:              True
exposed-modules:      Text.Sayable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sayable-1.2.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sayable-1.2.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sayable-1.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sayable
hs-libraries:         HSsayable-1.2.6.0-7j1RwjqNpHbAnkR423nlV8
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX
    template-haskell-2.20.0.0 text-2.0.2
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3

haddock-interfaces:   /usr/share/doc/haskell-sayable/html/sayable.haddock
haddock-html:         /usr/share/doc/haskell-sayable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

